@@ -12,9 +12,18 @@
 #' @export
 biogeoStatus <- function(signals) {
   signals <- as.data.frame(signals)
+  
+  if(NaN %in% unique(signals$signal_native32_10)){
+    signals$signal_native32_10[which(is.na(signals$signal_native32_10))] <- 0
+  }
+  
+  if(NaN %in% unique(signals$signal_alien32_10)){
+    signals$signal_alien32_10[which(is.na(signals$signal_alien32_10))] <- 0
+  }
+  
   model <- bRacatus::Model_biogeo
   biogeo <- predict(model, signals, type = "response")
   tab <- signals[, -((ncol(signals) - 3):ncol(signals))]
   tab <- cbind(tab, biogeoStatus = biogeo)
   return(tab)
-}
\ No newline at end of file
+}
