@@ -40,7 +40,7 @@ signalCalculation <- function(ref_reg, pts, biogeo = TRUE) {
                   unique_IDs[i])))
     dist <- try(suppressWarnings(readRDS(con)),silent =TRUE)
     
-    if(class(dist) == "try-error"){
+    if(inherits(dist, "try-error")){
       
       stop("Distance matrices not accessible due to connection issues.")
       
@@ -132,4 +132,4 @@ signalCalculation <- function(ref_reg, pts, biogeo = TRUE) {
   
   output <- cbind(occ_ID, df)
   return(output)
-}
\ No newline at end of file
+}
